@@ -1,7 +1,7 @@
 /**
- * @file folder.h feed list and plugin callbacks for folders
+ * @file folder.h feed list callbacks for folders
  * 
- * Copyright (C) 2006 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2006-2007 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,9 @@
 #ifndef _FOLDER_H
 #define _FOLDER_H
 
-#include "node.h"
+#include "node_type.h"
+
+#define IS_FOLDER(node) (node->type == folder_get_node_type ())
 
 /**
  * Returns the implementation of the folder node type.
