@@ -59,9 +59,9 @@ itemset_get_max_item_count (itemSetPtr itemSet)
 	return G_MAXUINT;
 }
 
-/* Generic merge logic suitable for feeds */
+/* Generic merge logic suitable for feeds (returns TRUE if merging instead of updating is necessary) */
 static gboolean
-itemset_generic_merge_check (GList *items, itemPtr newItem) 
+itemset_generic_merge_check (GList *items, itemPtr newItem, gboolean allowUpdates)
 {
 	GList		*oldItemIdIter = items;
 	itemPtr		oldItem = NULL;
@@ -122,20 +122,21 @@ itemset_generic_merge_check (GList *items, itemPtr newItem)
 	} else {
 		/* if the item was found but has other contents -> update contents */
 		if (!equal) {
-//			if (((feedPtr)(node_from_id(itemSet->nodeId)->data))->valid) {
-//				/* no item_set_new_status() - we don't treat changed items as new items! */
-//				item_set_title (oldItem, item_get_title (newItem));
-//				item_set_description (oldItem, item_get_description (newItem));
-//				oldItem->time = newItem->time;
-//				oldItem->updateStatus = TRUE;
-//				// FIXME: this does not remove metadata from DB
-//				metadata_list_free (oldItem->metadata);
-//				oldItem->metadata = newItem->metadata;
-//				newItem->metadata = NULL;
-//				debug0 (DEBUG_CACHE, "-> item already existing and was updated");
-//			} else {
-//				debug0 (DEBUG_CACHE, "-> item updates not merged because of parser errors");
-//			}
+			if (allowUpdates) {
+				/* no item_set_new_status() - we don't treat changed items as new items! */
+				item_set_title (oldItem, item_get_title (newItem));
+				item_set_description (oldItem, item_get_description (newItem));
+				oldItem->time = newItem->time;
+				oldItem->updateStatus = TRUE;
+				// FIXME: this does not remove metadata from DB
+				metadata_list_free (oldItem->metadata);
+				oldItem->metadata = newItem->metadata;
+				newItem->metadata = NULL;
+				db_item_update (oldItem);
+				debug0 (DEBUG_CACHE, "-> item already existing and was updated");
+			} else {
+				debug0 (DEBUG_CACHE, "-> item updates not merged because of parser errors");
+			}
 		} else {
 			debug0 (DEBUG_CACHE, "-> item already exists");
 		}
@@ -149,13 +150,13 @@ itemset_generic_merge_check (GList *items, itemPtr newItem)
  * into the itemset or if it was already added.
  */
 static gboolean
-itemset_merge_check (GList *items, itemPtr item)
+itemset_merge_check (GList *items, itemPtr item, gboolean allowUpdates)
 {
-	return itemset_generic_merge_check (items, item);	
+	return itemset_generic_merge_check (items, item, allowUpdates);
 }
 
 static gboolean
-itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item)
+itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gboolean allowUpdates)
 {
 	gboolean	merge;
 	nodePtr		node;
@@ -163,14 +164,14 @@ itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item)
 	debug2 (DEBUG_UPDATE, "trying to merge \"%s\" to node id \"%s\"", item_get_title (item), itemSet->nodeId);
 	
 	/* first try to merge with existing item */
-	merge = itemset_merge_check (items, item);
+	merge = itemset_merge_check (items, item, allowUpdates);
 
 	/* if it is a new item add it to the item set */	
 	if (merge) {
 		g_assert (itemSet->nodeId);
 		g_assert (!item->nodeId);
 		g_assert (!item->id);
-		item->nodeId = itemSet->nodeId;
+		item->nodeId = g_strdup (itemSet->nodeId);
 		
 		/* step 1: write item to DB */
 		db_item_update (item);
@@ -226,11 +227,31 @@ itemset_sort_by_date (gconstpointer a, gconstpointer b)
 	itemPtr item2 = (itemPtr)b;
 	
 	g_assert(item1 && item2);
-	return item1->time < item2->time;
+	
+	/* We have a problem here if all items of the feed
+	   do have no date, then this comparison is useless.
+	   To avoid such a case we alternatively compare by
+	   item id (which should be an ever-increasing number)
+	   and thereby indicate merge order as a secondary
+	   order criterion */
+	if (item1->time == item2->time) {
+		if (item1->id < item2->id)
+			return 1;
+		if (item1->id > item2->id) 
+			return -1;
+		return 0;
+	}
+		
+	if (item1->time < item2->time)
+		return 1;
+	if (item1->time > item2->time)
+		return -1;
+	
+	return 0;
 }
 
 guint
-itemset_merge_items (itemSetPtr itemSet, GList *list)
+itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates)
 {
 	GList	*iter, *droppedItems = NULL, *items = NULL;
 	guint	max, toBeDropped, newCount = 0;
@@ -239,7 +260,7 @@ itemset_merge_items (itemSetPtr itemSet, GList *list)
 	
 	debug2 (DEBUG_UPDATE, "old item set %p of (node id=%s):", itemSet, itemSet->nodeId);
 	
-	/* 1. Avoid cache wrapping
+	/* 1. Avoid cache wrapping (if feed size > cache size)
 	
 	   Truncate the new itemset if it is longer than
 	   the maximum cache size which could cause items
@@ -267,28 +288,36 @@ itemset_merge_items (itemSetPtr itemSet, GList *list)
 	/* 2. Preload all items for merging comparison */
 	iter = itemSet->ids;
 	while (iter) {
-		items = g_list_append (items, item_load (GPOINTER_TO_UINT (iter->data)));
+		itemPtr item = item_load (GPOINTER_TO_UINT (iter->data));
+		if (item)
+			items = g_list_append (items, item);
 		iter = g_list_next (iter);
 	}
  
-	/* 3. Merge items
+	/* 3. Merge received items to existing item set
 	 
 	   Items are given in top to bottom display order. 
 	   Adding them in this order would mean to reverse 
 	   their order in the merged list, so merging needs
-	   to be done bottom to top. */
+	   to be done bottom to top. During this step the
+	   item list (items) may exceed the cache limit. */
 	iter = g_list_last (list);
 	while (iter) {
-		if (itemset_merge_item (itemSet, items, ((itemPtr)iter->data)))
+		if (itemset_merge_item (itemSet, items, (itemPtr)iter->data, allowUpdates)) {
 			newCount++;
+			items = g_list_prepend (items, iter->data);
+		}
 		iter = g_list_previous (iter);
 	}
 	g_list_free (list);
 	
-	/* 4. Apply cache limit and unload items */
+	/* 4. Apply cache limit for effective item set size
+	      and unload older items as necessary. In this step
+	      it is important never to drop flagged items and 
+	      to drop the oldest items only. */
 	
-	if (newCount + g_list_length (items) > max)
-		toBeDropped = newCount + g_list_length (items) - max;
+	if (g_list_length (items) > max)
+		toBeDropped = g_list_length (items) - max;
 	else
 		toBeDropped = 0;
 		
@@ -300,7 +329,7 @@ itemset_merge_items (itemSetPtr itemSet, GList *list)
 		if (toBeDropped > 0 && !item->flagStatus) {
 			debug2 (DEBUG_UPDATE, "dropping item nr %u (%s)....", item->id, item_get_title (item));
 			droppedItems = g_list_append (droppedItems, item);
-			/* no unloading here, is done in itemlist_remove_items() */
+			/* no unloading here, it's done in itemlist_remove_items() */
 			toBeDropped--;
 		} else {
 			item_unload (item);
