@@ -72,7 +72,7 @@ nodePtr node_from_id(const gchar *id) {
 	g_assert(NULL != nodes);
 	node = (nodePtr)g_hash_table_lookup(nodes, id);
 	if(!node)
-		g_warning("Fatal: no node with id \"%s\" found!", id);
+		debug1(DEBUG_GUI, "Fatal: no node with id \"%s\" found!", id);
 		
 	return node;
 }
@@ -238,26 +238,6 @@ void node_update_counters(nodePtr node) {
 	node_update_parent_counters(node->parent);
 }
 
-void
-node_merge_items (nodePtr node, GList *items) 
-{
-	guint		newCount;
-	itemSetPtr	itemSet;
-	
-	itemSet = node_get_itemset (node);	
-	newCount = itemset_merge_items (itemSet, items);
-	itemlist_merge_itemset (itemSet);
-	itemset_free (itemSet);
-
-	if (newCount) {
-		vfolder_foreach_with_rule ("unread", vfolder_update_counters);
-		vfolder_foreach_with_rule ("flagged", vfolder_update_counters);
-	}
-			
-	node_update_counters (node);
-	feedlist_update_new_item_count (newCount);
-}
-
 // FIXME: bad interface, do not imply node icons are favicons
 void
 node_update_favicon (nodePtr node, GTimeVal *now)
@@ -275,7 +255,15 @@ node_update_favicon (nodePtr node, GTimeVal *now)
 itemSetPtr
 node_get_itemset (nodePtr node)
 {
-	return NODE_TYPE (node)->load (node);
+	itemSetPtr itemSet;
+	
+	debug_enter ("node_get_itemset");
+	
+	itemSet = NODE_TYPE (node)->load (node);
+	
+	debug_exit ("node_get_itemset");
+	
+	return itemSet;
 }
 
 void
