@@ -1,7 +1,7 @@
 /**
  * @file ui_popup.c popup menus
  *
- * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,16 +26,26 @@
 #include <libxml/uri.h>
 #include <string.h>
 
+#include "common.h"
 #include "feed.h"
+#include "feedlist.h"
+#include "folder.h"
+#include "itemlist.h"
 #include "node.h"
-#include "support.h"
-#include "callbacks.h"
+#include "newsbin.h"
 #include "social.h"
 #include "update.h"
-#include "ui/ui_popup.h"
-#include "ui/ui_mainwindow.h"
+#include "vfolder.h"
 #include "ui/ui_enclosure.h"
 #include "ui/ui_feedlist.h"
+#include "ui/ui_htmlview.h"
+#include "ui/ui_itemlist.h"
+#include "ui/ui_mainwindow.h"
+#include "ui/ui_popup.h"
+#include "ui/ui_prefs.h"
+#include "ui/ui_shell.h"
+#include "ui/ui_tabs.h"
+#include "fl_sources/node_source.h"
 
 /*------------------------------------------------------------------------------*/
 /* popup menu callbacks 							*/
@@ -131,6 +141,7 @@ void ui_popup_update_menues(void) {
 	addPopupOption(&item_menu_items, &item_menu_len, _("/Copy Item _URL to Clipboard"),     NULL, on_popup_copy_URL_clipboard,     		0, NULL, 0);
 	
 	addPopupOption(&item_menu_items, &item_menu_len, "/",					NULL, NULL, 					0, "<Separator>", 0);
+	addPopupOption(&item_menu_items, &item_menu_len, _("/Toggle _Read Status"),		NULL, on_popup_toggle_read, 			0, NULL, 0);
 	addPopupOption(&item_menu_items, &item_menu_len, _("/Toggle Item _Flag"),		NULL, on_popup_toggle_flag, 			0, NULL, 0);
 	addPopupOption(&item_menu_items, &item_menu_len, _("/R_emove Item"),			NULL, on_popup_remove_selected,			0, "<StockItem>", GTK_STOCK_DELETE);
 
@@ -237,35 +248,51 @@ GtkMenu *ui_popup_make_enclosure_menu(const gchar *url) {
 /* popup callback wrappers */
 
 static void ui_popup_update(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_update((nodePtr)callback_data, FEED_REQ_PRIORITY_HIGH);
+	node_update_subscription((nodePtr)callback_data, GUINT_TO_POINTER (FEED_REQ_PRIORITY_HIGH));
 }
 
-static void ui_popup_mark_as_read(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_mark_all_read((nodePtr)callback_data);
+static void
+ui_popup_mark_as_read (gpointer callback_data, guint callback_action, GtkWidget *widget) 
+{
+	feedlist_mark_all_read ((nodePtr)callback_data);
 }
 
-static void ui_popup_add_feed(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_interactive_add(NODE_TYPE_FEED);
+static void
+ui_popup_add_feed (gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	node_type_request_interactive_add (feed_get_node_type ());
 }
 
-static void ui_popup_add_folder(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_interactive_add(NODE_TYPE_FOLDER);
+static void
+ui_popup_add_folder(gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	node_type_request_interactive_add (folder_get_node_type ());
 }
 
-static void ui_popup_add_vfolder(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_interactive_add(NODE_TYPE_VFOLDER);
+static void
+ui_popup_add_vfolder (gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	node_type_request_interactive_add (vfolder_get_node_type ());
 }
 
-static void ui_popup_add_source(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_interactive_add(NODE_TYPE_SOURCE);
+static void
+ui_popup_add_source (gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	node_type_request_interactive_add (node_source_get_node_type ());
 }
 
-static void ui_popup_add_newsbin(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_interactive_add(NODE_TYPE_NEWSBIN);
+static void
+ui_popup_add_newsbin (gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	node_type_request_interactive_add (newsbin_get_node_type ());
 }
 
-static void ui_popup_properties(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	node_request_properties((nodePtr)callback_data);
+static void
+ui_popup_properties (gpointer callback_data, guint callback_action, GtkWidget *widget)
+{
+	nodePtr node = (nodePtr) callback_data;
+	
+	NODE_TYPE (node)->request_properties (node);
 }
 
 static void ui_popup_delete(gpointer callback_data, guint callback_action, GtkWidget *widget) {
@@ -282,11 +309,10 @@ static GtkMenu *ui_popup_node_menu(nodePtr node, gboolean validSelection) {
 	gint 			menu_len = 0;
 
 	if(validSelection) {
-		if(node->type == NODE_TYPE_FOLDER)
-			addPopupOption(&menu_items, &menu_len, _("/_Update Folder"), 	NULL, ui_popup_update,		0, "<StockItem>", GTK_STOCK_REFRESH);
-
-		if((node->type != NODE_TYPE_FOLDER) && (node->type != NODE_TYPE_VFOLDER))
+		if(NODE_TYPE(node)->capabilities & NODE_CAPABILITY_UPDATE)
 			addPopupOption(&menu_items, &menu_len, _("/_Update"), 		NULL, ui_popup_update,		0, "<StockItem>", GTK_STOCK_REFRESH);
+		else if(NODE_TYPE(node)->capabilities & NODE_CAPABILITY_UPDATE_CHILDS)
+			addPopupOption(&menu_items, &menu_len, _("/_Update Folder"), 	NULL, ui_popup_update,		0, "<StockItem>", GTK_STOCK_REFRESH);
 
 		addPopupOption(&menu_items, &menu_len, _("/_Mark All As Read"),		NULL, ui_popup_mark_as_read, 	0, "<StockItem>", GTK_STOCK_APPLY);
 	}
@@ -318,9 +344,11 @@ static GtkMenu *ui_popup_node_menu(nodePtr node, gboolean validSelection) {
 /* mouse button handler 							*/
 /*------------------------------------------------------------------------------*/
 
-gboolean on_mainfeedlist_button_press_event(GtkWidget *widget,
-                                            GdkEventButton *event,
-                                            gpointer user_data) {
+gboolean
+on_mainfeedlist_button_press_event (GtkWidget *widget,
+                                    GdkEventButton *event,
+                                    gpointer user_data)
+{
 	GdkEventButton 	*eb;
 	GtkWidget	*treeview;
 	GtkTreeModel	*model;
@@ -329,48 +357,48 @@ gboolean on_mainfeedlist_button_press_event(GtkWidget *widget,
 	gboolean	selected = TRUE;
 	nodePtr		node = NULL;
 
-	treeview = lookup_widget(mainwindow, "feedlist");
-	g_assert(treeview);
+	treeview = liferea_shell_lookup ("feedlist");
+	g_assert (treeview);
 
-	if(event->type != GDK_BUTTON_PRESS)
+	if (event->type != GDK_BUTTON_PRESS)
 		return FALSE;
 
 	eb = (GdkEventButton*)event;
 
 	/* determine node */	
-	if(!gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(lookup_widget(mainwindow, "feedlist")), event->x, event->y, &path, NULL, NULL, NULL)) {
-		selected=FALSE;
-		node = feedlist_get_root();
+	if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview), event->x, event->y, &path, NULL, NULL, NULL)) {
+		selected = FALSE;
+		node = feedlist_get_root ();
 	} else {
-		model = gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(mainwindow, "feedlist")));
-		gtk_tree_model_get_iter(model, &iter, path);
-		gtk_tree_path_free(path);
-		gtk_tree_model_get(model, &iter, FS_PTR, &node, -1);
+		model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
+		gtk_tree_model_get_iter (model, &iter, path);
+		gtk_tree_path_free (path);
+		gtk_tree_model_get (model, &iter, FS_PTR, &node, -1);
 	}
 	
 	/* apply action */
-	switch(eb->button) {
+	switch (eb->button) {
 		default:
 			/* Shouldn't happen... */
 			return FALSE;
 			break;
 		case 2:
-			if(node) {
-				node_mark_all_read(node);
-				itemview_update_node_info(node->itemSet);
-				itemview_update();
+			if (node) {
+				feedlist_mark_all_read (node);
+				itemview_update_node_info (node);
+				itemview_update ();
 			}
 			break;
 		case 3:
-			if(node) {
-				ui_feedlist_select(node);
+			if (node) {
+				ui_feedlist_select (node);
 			} else {
 				/* This happens when an "empty" node or nothing (feed list root) is clicked */
 				selected = FALSE;
-				node = feedlist_get_root();
+				node = feedlist_get_root ();
 			}
 
-			gtk_menu_popup(ui_popup_node_menu(node, selected), NULL, NULL, NULL, NULL, eb->button, eb->time);
+			gtk_menu_popup (ui_popup_node_menu (node, selected), NULL, NULL, NULL, NULL, eb->button, eb->time);
 			break;
 	}
 			
